==> nui_core-0.0.3.tar.gz: lib/ui/component/nui_stacked_avatars.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/model/gradient_background.dart';
import 'package:nui_core/nui_core.dart';

class NUIStackedAvatars extends StatefulWidget {
  NUIStackedAvatars(this.images, {this.stackRatio: 0.3, this.moreCount, this.avatarRadius: 15, this.divider: 0, this.outline: NUIColors.NUIWhite, this.thickness: 2, this.background: NUIColors.NUISkeletalGray, this.textStyle, this.textBackground, Key key}): super(key: key);
  final double stackRatio;
  final double avatarRadius;
  final Color outline;
  final double divider;
  final double thickness;
  final int moreCount;
  final Color background;
  final TextStyle textStyle;
  final List<ImageProvider> images;
  final GradientBackground textBackground;
  @override
  _NUIStackedAvatarsState createState() => _NUIStackedAvatarsState();
}

class _NUIStackedAvatarsState extends State<NUIStackedAvatars> {
  @override
  Widget build(BuildContext context) {
    final avatars = _generataAvatars();

    if(widget.stackRatio <= 0){
      return NUIRow(
        children: avatars,
        divider: VerticalDivider(color: NUIColors.NUITransparent, width: widget.divider,),
      );
    }
    else{
      return Stack(
        children: _generatePositionedAvatars(avatars),
      );
    }
  }

  List<Widget> _generatePositionedAvatars(List<Widget> avatars){
    final items = List<Widget>();
    double offset = 0;
    final itemOffset = (widget.avatarRadius*2)*(1-widget.stackRatio);
    loop(avatars, (item, position, isFirst, isLast){
      final positioned = Positioned(
          child: item,
          top: 0,
          left: offset,
      );
      items.add(positioned);
      offset = offset + itemOffset;
    });
    return items;
  }

  List<Widget> _generataAvatars(){
    List<Widget> avatars = List();
    for(ImageProvider img in widget.images){
      final avatar = NUIOutlineCircleAvatar(image: img, radius: widget.avatarRadius, thickness: widget.thickness, outlineColor: widget.outline, innerColor: widget.background);
      avatars.add(avatar);
    }
    if(widget.moreCount != null && widget.moreCount > 0){
      avatars.add(Container(
        height: widget.avatarRadius*2,
        width: widget.avatarRadius*2,
        decoration: NUIOutlineDecoration(thickness: widget.thickness, radius: BorderRadius.circular(widget.avatarRadius), outlineColor: widget.outline, innerColor: widget.outline),
        padding: EdgeInsets.all(widget.thickness),
        child: Container(
          height: double.infinity,
          width: double.infinity,
          alignment: Alignment.center,
          decoration: NUIBoxDecoration(
            gradient: NUILinearGradient(colors: widget.textBackground?.colors() ?? NUIGradientBackgrounds.getDefaultGradientBackgrounds()[0].colors(), orientation: GradientOrientation.T_B)
          ),
          child: Text(
            widget.moreCount.toString() + "+",
            textAlign: TextAlign.start,
            overflow: TextOverflow.ellipsis,
            style: widget.textStyle,
          ),
        ),
      ));
    }
    return avatars;
  }
}

==> nui_core-0.0.85.tar.gz: lib/ui/component/nui_stacked_avatars.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/model/gradient_background.dart';
import 'package:nui_core/nui_core.dart';

class NUIStackedAvatars extends StatefulWidget {
  NUIStackedAvatars(this.images, {this.stackRatio: 0.3, this.moreCount, this.avatarRadius: 15, this.divider: 0, this.outline: NUIColors.NUIWhite, this.thickness: 2, this.background: NUIColors.NUISkeletalGray, this.textStyle, this.textBackground, Key key}): super(key: key);
  final double stackRatio;
  final double avatarRadius;
  final Color outline;
  final double divider;
  final double thickness;
  final int moreCount;
  final Color background;
  final TextStyle textStyle;
  final List<ImageProvider> images;
  final GradientBackground textBackground;
  @override
  _NUIStackedAvatarsState createState() => _NUIStackedAvatarsState();
}

class _NUIStackedAvatarsState extends State<NUIStackedAvatars> {
  @override
  Widget build(BuildContext context) {
    final avatars = _generateAvatars();

    if(widget.stackRatio <= 0){
      return NUIRow(
        children: avatars,
        divider: VerticalDivider(color: NUIColors.NUITransparent, width: widget.divider,),
      );
    }
    else{
      return Container(
        width: _calculateStackWidth(avatars.length),
        height: widget.avatarRadius*2,
        child: Stack(
          children: _generatePositionedAvatars(avatars),
        ),
      );
    }
  }

  double _calculateStackWidth(int count){
    if(count == 0) return 0;
    final fullWidth = widget.avatarRadius*2;
    final itemOffset = fullWidth*(widget.stackRatio);
    final width = fullWidth + (fullWidth - itemOffset)*(count - 1);
    return width;
  }

  List<Widget> _generatePositionedAvatars(List<Widget> avatars){
    final items = List<Widget>();
    double offset = 0;
    final itemOffset = (widget.avatarRadius*2)*(1-widget.stackRatio);
    loop(avatars, (item, position, isFirst, isLast){
      final positioned = Positioned(
          child: item,
          top: 0,
          left: offset,
      );
      items.add(positioned);
      offset = offset + itemOffset;
    });
    return items;
  }

  List<Widget> _generateAvatars(){
    List<Widget> avatars = List();
    for(ImageProvider img in widget.images){
      final avatar = NUIOutlineCircleAvatar(image: img, radius: widget.avatarRadius, thickness: widget.thickness, outlineColor: widget.outline, innerColor: widget.background);
      avatars.add(avatar);
    }
    if(widget.moreCount != null && widget.moreCount > 0){
      avatars.add(Container(
        height: widget.avatarRadius*2,
        width: widget.avatarRadius*2,
        decoration: NUIOutlineDecoration(thickness: widget.thickness, radius: BorderRadius.circular(widget.avatarRadius), outlineColor: widget.outline, innerColor: widget.outline),
        padding: EdgeInsets.all(widget.thickness),
        child: Container(
          height: double.infinity,
          width: double.infinity,
          alignment: Alignment.center,
          decoration: NUIBoxDecoration(
            gradient: NUILinearGradient(colors: widget.textBackground?.colors() ?? NUIGradientBackgrounds.getDefaultGradientBackgrounds()[0].colors(), orientation: GradientOrientation.T_B)
          ),
          child: Text(
            widget.moreCount.toString() + "+",
            textAlign: TextAlign.start,
            overflow: TextOverflow.ellipsis,
            style: widget.textStyle,
          ),
        ),
      ));
    }
    return avatars;
  }
}
